@@ -44,7 +44,14 @@ fi
 # Registered process to wait for to consider start a success
 WAIT_FOR_PROCESS=riak_core_node_watcher
 
-WHOAMI=`whoami`
+WHOAMI=`id -un`
+
+# erlexec requires HOME to be set. The username needs to be a
+# unquoted literal because of the tilde expansion, hence the
+# usage of eval.
+if [ -z "$HOME" ]; then
+    export HOME=`eval echo "~$WHOAMI"`
+fi
 
 # Echo to stderr on errors
 echoerr() { echo "$@" 1>&2; }
@@ -231,8 +238,8 @@ check_user() {
         #     riak-admin bucket-type create mytype {props: {n_val: 4}}
         #  after the arguments were passed into the new shell during exec su
         #
-        # So this regex finds any '"', '{', or '}' and prepends with a '\'
-        ESCAPED_ARGS=`echo "$@" | sed -e 's/\([{}"]\)/\\\\\1/g'`
+        # So this regex finds any '(', ')', "'" , '"', '{', or '}' and prepends with a '\'
+        ESCAPED_ARGS=$(echo "$@" | sed -e "s/\([\\\(\\\){}\"']\)/\\\\\1/g")
 
         # This will drop priviledges into the runner user
         # It exec's in a new shell and the current shell will exit
@@ -265,7 +272,7 @@ node_down_check() {
 node_up_check() {
     MUTE=`ping_node 2> /dev/null`
     if [ "$?" -ne 0 ]; then
-        echoerr "Node is not running!"
+        echoerr "Node did not respond to ping!"
         exit 1
     fi
 }
